#
# spec file for package flacon
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2014-2018 Alexander Evseev <aevseev@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flacon
Version:        7.0.1
Release:        bp154.1.68
Summary:        Audio File Encoder
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://flacon.github.io/
Source:         https://github.com/flacon/flacon/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(uchardet)
Recommends:     faac
Recommends:     flac
Recommends:     lame
Recommends:     mac
Recommends:     mp3gain
Recommends:     opus-tools
Recommends:     sox
Recommends:     ttaenc
Recommends:     vorbis-tools
Recommends:     vorbisgain
Recommends:     wavpack

%description
Flacon extracts individual tracks from one big audio file containing the entire
album of music and saves them as separate audio files. To do this, it uses
information from the appropriate CUE file. Besides, Flacon makes it possible
to conveniently revise or specify tags both for all tracks at once or for each
tag separately.

%lang_package

%prep
%autosetup

%build
%cmake
%cmake_build

%install
%cmake_install
%find_lang %{name} --with-qt

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/flacon.png
%{_datadir}/icons/hicolor/scalable/apps/flacon.svg
%{_datadir}/metainfo/com.github.Flacon.metainfo.xml
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations

%changelog
* Tue Apr 27 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.0.1
  * Added informative error messages when the program can't load
    an audio file:
    + The audio file does not exist.
    + The audio file may be corrupted or an unsupported audio
    format.
    + Decoder program is not installed.
    + Decoder program is installed in the settings but binary
    file does not exist.
  * Improved warning messages:
    + Do not show a warning if the output format does not
    support the quality of the input HD audio, but you have
    set the correct bits per sample and sample rate in the
    preferences.
  * Redesigned the logic of loading CUE files containing
    multiple files, for example, 2 sides of an LP. Now they are
    displayed as a single list, have a single track numbering,
    and allow you to change album tags in a single operation.
  * Fixed: Flacon refuses to compute ReplayGain for no good
    reason.
  * Improved search for covers arts.
  * Added better icons for dark themes.
  * Added a few codepages for some East Asian languages.
  * Translations updated.
* Sat Jun 27 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.1.0
  * Save TOTALDISCS and DISCNUMBER tags to the output CUE file.
  * Now the program removes temporary files more carefully.
  * Imporove main menu items.
  * Because freedb.org died, the program uses gnudb.org instead.
    Added a graphical interface for selecting other CDDB
    servers.
  * Translations updated.
* Sun May 31 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.0.0
  * Added support of profiles, you can have different encoding
    options for different cases, such as maximum quality for your
    computer, and CD quality for your phone.
  * Improved usability of the preferences dialog.
  * Now the program generates file names that are safe for
    Windows file systems.
  * Support for sampling rates greater than 192000 Hz.
  * When used in console mode, the program prints information
    about the status of tracks conversion.
  * Many small improvements and bug fixes.
  * Translations updated.
* Fri Mar 13 2020 Luigi Baldoni <aloisio@gmx.com>
- Recommend faac
- Remove obsolete -lang Recommends
* Sun Feb 23 2020 Kyrill Detinov <lazy.kent@opensuse.org>
- Fix runtime dependencies: doesn't require shntool.
- Add Recommends: mp3gain, ttaenc.
* Wed Nov 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v5.5.1)
